@@ -1,4 +1,4 @@
-/* $Id: color.c 4367 2009-02-07 14:48:30Z astyanax $ */
+/* $Id: color.c 4379 2009-02-16 23:06:09Z astyanax $ */
 /**************************************************************************
  *   color.c                                                              *
  *                                                                        *
@@ -268,6 +268,16 @@ void reset_multis_after(filestruct *fileptr, int mindex)
 	else
 	    break;
     }
+    for (; oof != NULL; oof = oof->next) {
+	alloc_multidata_if_needed(oof);
+	if (oof->multidata == NULL)
+	    continue;
+	if (oof->multidata[mindex] == CNONE)
+	    oof->multidata[mindex] = -1;
+	else
+	    break;
+    }
+    edit_refresh_needed = TRUE;
 }
 
 void reset_multis_before(filestruct *fileptr, int mindex)
@@ -282,11 +292,31 @@ void reset_multis_before(filestruct *fileptr, int mindex)
 	else
 	    break;
     }
+    for (; oof != NULL; oof = oof->prev) {
+	alloc_multidata_if_needed(oof);
+	if (oof->multidata == NULL)
+	    continue;
+	if (oof->multidata[mindex] == CNONE)
+	    oof->multidata[mindex] = -1;
+	else
+	    break;
+    }
+
+    edit_refresh_needed = TRUE;
 }
 
+/* Reset one multiline regex info */
+void reset_multis_for_id(filestruct *fileptr, int num)
+{
+    reset_multis_before(fileptr, num);
+    reset_multis_after(fileptr, num);
+    fileptr->multidata[num] = -1;
+}
 
-/* Reset multi line strings around a filestruct ptr, trying to be smart about stopping */
-void reset_multis(filestruct *fileptr)
+/* Reset multi line strings around a filestruct ptr, trying to be smart about stopping
+   force = reset everything regardless, useful when we don't know how much screen state
+           has changed  */
+void reset_multis(filestruct *fileptr, bool force)
 {
     int nobegin, noend;
     regmatch_t startmatch, endmatch;
@@ -302,6 +332,11 @@ void reset_multis(filestruct *fileptr)
 	    continue;
 
 	alloc_multidata_if_needed(fileptr);
+	if (force == TRUE) {
+	    reset_multis_for_id(fileptr, tmpcolor->id);
+	    continue;
+	}
+
 	/* Figure out where the first begin and end are to determine if
 	   things changed drastically for the precalculated multi values */
         nobegin = regexec(tmpcolor->start, fileptr->data, 1, &startmatch, 0);
@@ -309,16 +344,17 @@ void reset_multis(filestruct *fileptr)
 	if (fileptr->multidata[tmpcolor->id] ==  CWHOLELINE) {
 	    if (nobegin && noend)
 		continue;
-	} else if (fileptr->multidata[tmpcolor->id] & CBEGINBEFORE && !noend
+	} else if (fileptr->multidata[tmpcolor->id] == CNONE) {
+	    if (nobegin && noend)
+		continue;
+	}  else if (fileptr->multidata[tmpcolor->id] & CBEGINBEFORE && !noend
 	  && (nobegin || endmatch.rm_eo > startmatch.rm_eo)) {
 	    reset_multis_after(fileptr, tmpcolor->id);
 	    continue;
 	}
 
 	/* If we got here assume the worst */
-	reset_multis_before(fileptr, tmpcolor->id);
-	reset_multis_after(fileptr, tmpcolor->id);
-	fileptr->multidata[tmpcolor->id] = -1;
+	reset_multis_for_id(fileptr, tmpcolor->id);
     }
 }
 #endif /* ENABLE_COLOR */
