@@ -1,4 +1,4 @@
-/* $Id: cut.c 4339 2008-10-14 01:14:12Z astyanax $ */
+/* $Id: cut.c 4379 2009-02-16 23:06:09Z astyanax $ */
 /**************************************************************************
  *   cut.c                                                                *
  *                                                                        *
@@ -211,9 +211,12 @@ void do_cut_text(
 	 * modified. */
 	set_modified();
 
-
     /* Update the screen. */
-    edit_refresh();
+    edit_refresh_needed = TRUE;
+
+#ifdef ENABLE_COLOR
+    reset_multis(openfile->current, FALSE);
+#endif
 
 #ifdef DEBUG
     dump_filestruct(cutbuffer);
@@ -276,7 +279,11 @@ void do_uncut_text(void)
     set_modified();
 
     /* Update the screen. */
-    edit_refresh();
+    edit_refresh_needed = TRUE;
+
+#ifdef ENABLE_COLOR
+    reset_multis(openfile->current, FALSE);
+#endif
 
 #ifdef DEBUG
     dump_filestruct_reverse();
