@@ -1,4 +1,4 @@
-/* $Id: nano.c 4364 2009-02-06 03:41:02Z astyanax $ */ 
+/* $Id: nano.c 4381 2009-02-17 03:05:17Z astyanax $ */ 
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
@@ -879,6 +879,8 @@ void usage(void)
 #endif
     print_opt("-p", "--preserve",
 	N_("Preserve XON (^Q) and XOFF (^S) keys"));
+    print_opt("-q", "--quiet",
+	N_("Silently ignore startup issues like rc file errors"));
 #ifndef DISABLE_WRAPJUSTIFY
     print_opt(_("-r <#cols>"), _("--fill=<#cols>"),
 	N_("Set wrapping point at column #cols"));
@@ -1588,27 +1590,32 @@ int do_input(bool *meta_key, bool *func_key, bool *s_or_t, bool
 			*ran_func = TRUE;
 			if (ISSET(VIEW_MODE) && f && !f->viewok)
 			    print_view_warning();
-			else
+			else {
 #ifndef NANO_TINY
 			    if (s->scfunc ==  DO_TOGGLE)
 				do_toggle(s->toggle);
 			    else {
+#else
+			    {
 #endif
 				iso_me_harder_funcmap(s->scfunc);
 #ifdef ENABLE_COLOR
-				if (!f->viewok && openfile->syntax != NULL 
-					&& openfile->current->multidata && openfile->syntax->nmultis > 0) {
-				    reset_multis(openfile->current);
+				if (!f->viewok && openfile->syntax != NULL
+					&& openfile->syntax->nmultis > 0) {
+				    reset_multis(openfile->current, FALSE);
 				}
 				if (edit_refresh_needed) {
+#ifdef DEBUG
+	    			    fprintf(stderr, "running edit_refresh() as edit_refresh_needed is true\n");
+#endif
 				    edit_refresh();
 				    edit_refresh_needed = FALSE;
 				}
+
 #endif
 			    }
-#ifndef NANO_TINY
+			}
 		    }
-#endif
 		    *finished = TRUE;
 		    break;
 	    }
@@ -1690,6 +1697,9 @@ void alloc_multidata_if_needed(filestruct *fileptr)
    rendering (with any hope at all...) */
 void precalc_multicolorinfo(void)
 {
+#ifdef DEBUG
+	    fprintf(stderr, "entering precalc_multicolorinfo()\n");
+#endif
     if (openfile->colorstrings != NULL && !ISSET(NO_COLOR_SYNTAX)) {
 	const colortype *tmpcolor = openfile->colorstrings;
 	regmatch_t startmatch, endmatch;
@@ -1708,9 +1718,19 @@ void precalc_multicolorinfo(void)
 	    /* If it's not a multi-line regex, amscray */
 	    if (tmpcolor->end == NULL)
 		continue;
+#ifdef DEBUG
+	    fprintf(stderr, "working on color id %d\n", tmpcolor->id);
+#endif
+
 
 	    for (fileptr = openfile->fileage; fileptr != NULL; fileptr = fileptr->next) {
 		int startx = 0;
+		int nostart = 0;
+
+
+#ifdef DEBUG
+	    fprintf(stderr, "working on lineno %d\n", fileptr->lineno);
+#endif
 
 		alloc_multidata_if_needed(fileptr);
 
@@ -1720,44 +1740,84 @@ void precalc_multicolorinfo(void)
 	   		goto precalc_cleanup;
 		}
 
-		fileptr->multidata[tmpcolor->id] = CNONE;
-		while (regexec(tmpcolor->start, &fileptr->data[startx], 1, &startmatch, 0)  == 0) {
+		while ((nostart = regexec(tmpcolor->start, &fileptr->data[startx], 1, &startmatch, 0))  == 0) {
 		    /* Look for end and start marking how many lines are encompassed
 		       whcih should speed up rendering later */
-		     startx += startmatch.rm_eo;
+		    startx += startmatch.rm_eo;
+#ifdef DEBUG
+		    fprintf(stderr, "match found at pos %d...", startx);
+#endif
 
 		    /* Look on this line first for end */
 		    if (regexec(tmpcolor->end, &fileptr->data[startx], 1, &endmatch, 0)  == 0) {
 			startx += endmatch.rm_eo;
 			fileptr->multidata[tmpcolor->id] |= CSTARTENDHERE;
+#ifdef DEBUG
+	    fprintf(stderr, "end found on this line\n");
+#endif
 			continue;
 		    }
 
 		    /* Nice, we didn't find the end regex on this line.  Let's start looking for it */
 		    for (endptr = fileptr->next; endptr != NULL; endptr = endptr->next) {
 
+#ifdef DEBUG
+	    fprintf(stderr, "advancing to line %d to find end...\n", endptr->lineno);
+#endif
 			/* Check for keyboard input  again */
 			if ((cur_check = time(NULL)) - last_check > 1) {
 			    last_check = cur_check;
 			    if (wgetch(edit) != ERR)
 		   		goto precalc_cleanup;
 			}
-			if (regexec(tmpcolor->end, &endptr->data[startx], 1, &endmatch, 0) == 0)
+			if (regexec(tmpcolor->end, endptr->data, 1, &endmatch, 0) == 0)
 			   break;
 		    }
 
-		    if (endptr == NULL)
+		    if (endptr == NULL) {
+#ifdef DEBUG
+	    		fprintf(stderr, "no end found, breaking out\n");
+#endif
 			break;
+		    }
+
+
+#ifdef DEBUG
+		    fprintf(stderr, "end found\n");
+#endif
 
 		    /* We found it, we found it, la la la la la.  Mark all the
 			lines in between and the ends properly */
 		    fileptr->multidata[tmpcolor->id] |= CENDAFTER;
+#ifdef DEBUG
+		    fprintf(stderr, "marking line %d as CENDAFTER\n", fileptr->lineno);
+#endif
 		    for (fileptr = fileptr->next; fileptr != endptr; fileptr = fileptr->next) {
 			alloc_multidata_if_needed(fileptr);
 			fileptr->multidata[tmpcolor->id] = CWHOLELINE;
+#ifdef DEBUG
+			fprintf(stderr, "marking intermediary line %d as CWHOLELINE\n", fileptr->lineno);
+#endif
 		    }
 		    alloc_multidata_if_needed(endptr);
+#ifdef DEBUG
+		    fprintf(stderr, "marking line %d as BEGINBEFORE\n", fileptr->lineno);
+#endif
 		    endptr->multidata[tmpcolor->id] |= CBEGINBEFORE;
+		    /* We should be able to skip all the way to the line of the match.
+			This may introduce more bugs but it's the Right Thing to do */
+		    fileptr = endptr;
+		    startx = endmatch.rm_eo;
+#ifdef DEBUG
+		    fprintf(stderr, "jumping to line %d pos %d to continue\n", endptr->lineno, startx);
+#endif
+		}
+		if (nostart && startx == 0) {
+#ifdef DEBUG
+		    fprintf(stderr, "no start found on line %d, continuing\n", fileptr->lineno);
+#endif
+		    fileptr->multidata[tmpcolor->id] = CNONE;
+		    continue;
 		}
 	    }
 	}
@@ -1835,7 +1895,6 @@ void do_output(char *output, size_t output_len, bool allow_cntrls)
 #ifndef NANO_TINY
 	update_undo(ADD);
 
-
 	/* Note that current_x has not yet been incremented. */
 	if (openfile->mark_set && openfile->current ==
 		openfile->mark_begin && openfile->current_x <
@@ -1873,7 +1932,7 @@ void do_output(char *output, size_t output_len, bool allow_cntrls)
 
 
 #ifdef ENABLE_COLOR
-    reset_multis(openfile->current);
+    reset_multis(openfile->current, FALSE);
 #endif
     if (do_refresh) {
 	edit_refresh();
@@ -1930,6 +1989,7 @@ int main(int argc, char **argv)
 	{"operatingdir", 1, NULL, 'o'},
 #endif
 	{"preserve", 0, NULL, 'p'},
+	{"quiet", 0, NULL, 'q'},
 #ifndef DISABLE_WRAPJUSTIFY
 	{"fill", 1, NULL, 'r'},
 #endif
@@ -1993,11 +2053,11 @@ int main(int argc, char **argv)
     while ((optchr =
 #ifdef HAVE_GETOPT_LONG
 	getopt_long(argc, argv,
-		"h?ABC:DEFHIKLNOQ:RST:UVWY:abcdefgijklmo:pr:s:tvwxz",
+		"h?ABC:DEFHIKLNOQ:RST:UVWY:abcdefgijklmo:pqr:s:tvwxz",
 		long_options, NULL)
 #else
 	getopt(argc, argv,
-		"h?ABC:DEFHIKLNOQ:RST:UVWY:abcdefgijklmo:pr:s:tvwxz")
+		"h?ABC:DEFHIKLNOQ:RST:UVWY:abcdefgijklmo:pqr:s:tvwxz")
 #endif
 		) != -1) {
 	switch (optchr) {
@@ -2125,6 +2185,9 @@ int main(int argc, char **argv)
 	    case 'p':
 		SET(PRESERVE);
 		break;
+	    case 'q':
+		SET(QUIET);
+		break;
 #ifndef DISABLE_WRAPJUSTIFY
 	    case 'r':
 		if (!parse_num(optarg, &wrap_at)) {
