@@ -1,4 +1,4 @@
-/* $Id: proto.h 4367 2009-02-07 14:48:30Z astyanax $ */
+/* $Id: proto.h 4378 2009-02-16 21:04:00Z astyanax $ */
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
@@ -543,7 +543,7 @@ void parse_syntax(char *ptr);
 void parse_include(char *ptr);
 short color_to_short(const char *colorname, bool *bright);
 void parse_colors(char *ptr, bool icase);
-void reset_multis(filestruct *fileptr);
+void reset_multis(filestruct *fileptr, bool force);
 void alloc_multidata_if_needed(filestruct *fileptr);
 #endif
 void parse_rcfile(FILE *rcstream
