@@ -1,4 +1,4 @@
-/* $Id: rcfile.c 4365 2009-02-07 00:01:40Z astyanax $ */
+/* $Id: rcfile.c 4375 2009-02-11 05:45:57Z astyanax $ */
 /**************************************************************************
  *   rcfile.c                                                             *
  *                                                                        *
@@ -84,6 +84,7 @@ static const rcoption rcopts[] = {
     {"historylog", HISTORYLOG},
     {"matchbrackets", 0},
     {"noconvert", NO_CONVERT},
+    {"quiet", QUIET},
     {"quickblank", QUICK_BLANK},
     {"smarthome", SMART_HOME},
     {"smooth", SMOOTH_SCROLL},
@@ -117,6 +118,9 @@ void rcfile_error(const char *msg, ...)
 {
     va_list ap;
 
+    if (ISSET(QUIET))
+	return;
+
     fprintf(stderr, "\n");
     if (lineno > 0) {
 	errors = TRUE;
@@ -388,41 +392,41 @@ void parse_keybinding(char *ptr)
 
     if (keycopy[0] != 'M' && keycopy[0] != '^' && keycopy[0] != 'F' && keycopy[0] != 'K') {
 	rcfile_error(
-		N_("keybindings must begin with \"^\", \"M\", or \"F\"\n"));
+		N_("keybindings must begin with \"^\", \"M\", or \"F\""));
 	return;
     }
 
     funcptr = ptr;
     ptr = parse_next_word(ptr);
 
-    if (funcptr == NULL) {
+    if (!strcmp(funcptr, "")) {
 	rcfile_error(
-		N_("Must specify function to bind key to\n"));
+		N_("Must specify function to bind key to"));
 	return;
     }
 
     menuptr = ptr;
     ptr = parse_next_word(ptr);
 
-    if (menuptr == NULL) {
+    if (!strcmp(menuptr, "")) {
 	rcfile_error(
 		/* Note to translators, do not translate the word "all"
 		   in the sentence below, everything else is fine */
-		N_("Must specify menu bind key to (or \"all\")\n"));
-	return;
-    }
-
-    menu = strtomenu(menuptr);
-    if (menu < 1) {
-	rcfile_error(
-		N_("Could not map name \"%s\" to a menu\n"), menuptr);
+		N_("Must specify menu to bind key to (or \"all\")"));
 	return;
     }
 
     newsc = strtosc(menu, funcptr);
     if (newsc == NULL) {
 	rcfile_error(
-		N_("Could not map name \"%s\" to a function\n"), funcptr);
+		N_("Could not map name \"%s\" to a function"), funcptr);
+	return;
+    }
+
+    menu = strtomenu(menuptr);
+    if (menu < 1) {
+	rcfile_error(
+		N_("Could not map name \"%s\" to a menu"), menuptr);
 	return;
     }
 
@@ -444,7 +448,7 @@ void parse_keybinding(char *ptr)
 
     if (check_bad_binding(newsc)) {
 	rcfile_error(
-		N_("Sorry, keystr \"%s\" is an illegal binding\n"), newsc->keystr);
+		N_("Sorry, keystr \"%s\" is an illegal binding"), newsc->keystr);
 	return;
     }
 
@@ -470,7 +474,7 @@ void parse_include(char *ptr)
 {
     struct stat rcinfo;
     FILE *rcstream;
-    char *option, *nanorc_save = nanorc;
+    char *option, *nanorc_save = nanorc, *expanded;
     size_t lineno_save = lineno;
 
     option = ptr;
@@ -491,20 +495,22 @@ void parse_include(char *ptr)
 	}
     }
 
+    expanded = real_dir_from_tilde(option);
+
     /* Open the new syntax file. */
-    if ((rcstream = fopen(option, "rb")) == NULL) {
-	rcfile_error(_("Error reading %s: %s"), option,
+    if ((rcstream = fopen(expanded, "rb")) == NULL) {
+	rcfile_error(_("Error reading %s: %s"), expanded,
 		strerror(errno));
 	return;
     }
 
     /* Use the name and line number position of the new syntax file
      * while parsing it, so we can know where any errors in it are. */
-    nanorc = option;
+    nanorc = expanded;
     lineno = 0;
 
 #ifdef DEBUG
-    fprintf(stderr, "Parsing file \"%s\"\n", option);
+    fprintf(stderr, "Parsing file \"%s\" (expanded from \"%s\")\n", expanded, option);
 #endif
 
     parse_rcfile(rcstream
@@ -1057,15 +1063,6 @@ void parse_rcfile(FILE *rcstream
     lineno = 0;
 
     check_vitals_mapped();
-
-    if (errors) {
-	errors = FALSE;
-	fprintf(stderr,
-		_("\nPress Enter to continue starting nano.\n"));
-	while (getchar() != '\n')
-	    ;
-    }
-
     return;
 }
 
@@ -1146,6 +1143,14 @@ void do_rcfile(void)
     free(nanorc);
     nanorc = NULL;
 
+    if (errors && !ISSET(QUIET)) {
+	errors = FALSE;
+	fprintf(stderr,
+		_("\nPress Enter to continue starting nano.\n"));
+	while (getchar() != '\n')
+	    ;
+    }
+
 #ifdef ENABLE_COLOR
     set_colorpairs();
 #endif
