@@ -1,4 +1,4 @@
-/* $Id: text.c 4364 2009-02-06 03:41:02Z astyanax $ */ 
+/* $Id: text.c 4379 2009-02-16 23:06:09Z astyanax $ */ 
 /**************************************************************************
  *   text.c                                                               *
  *                                                                        *
@@ -140,13 +140,6 @@ void do_delete(void)
 
     set_modified();
 
-#ifdef ENABLE_COLOR
-    /* If color syntaxes are available and turned on, we need to call
-     * edit_refresh(). */
-    if (openfile->colorstrings != NULL && !ISSET(NO_COLOR_SYNTAX))
-	do_refresh = TRUE;
-#endif
-
     if (do_refresh)
 	edit_refresh_needed = TRUE;
     else
